PaletteColors enum
Enum for palette colors.
Values
- voidBlack → const PaletteColors
-
const PaletteColors(0, "VOID") - white → const PaletteColors
-
const PaletteColors(1, "WHITE") - grey → const PaletteColors
-
const PaletteColors(2, "GREY") - red → const PaletteColors
-
const PaletteColors(3, "RED") - pink → const PaletteColors
-
const PaletteColors(4, "PINK") - darkBrown → const PaletteColors
-
const PaletteColors(5, "DARKBROWN") - brown → const PaletteColors
-
const PaletteColors(6, "BROWN") - orange → const PaletteColors
-
const PaletteColors(7, "ORANGE") - yellow → const PaletteColors
-
const PaletteColors(8, "YELLOW") - darkGreen → const PaletteColors
-
const PaletteColors(9, "DARKGREEN") - green → const PaletteColors
-
const PaletteColors(10, "GREEN") - lightGreen → const PaletteColors
-
const PaletteColors(11, "LIGHTGREEN") - nightBlue → const PaletteColors
-
const PaletteColors(12, "NIGHTBLUE") - seaBlue → const PaletteColors
-
const PaletteColors(13, "SEABLUE") - skyBlue → const PaletteColors
-
const PaletteColors(14, "SKYBLUE") - cloudBlue → const PaletteColors
-
const PaletteColors(15, "CLOUDBLUE")
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - paletteIndex → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator +(
int value) → PaletteColors - Operator overload to add an integer value to a PaletteColor.
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromIndex(
int index) → PaletteColors - Returns the PaletteColor corresponding to the given index.
Constants
-
values
→ const List<
PaletteColors> - A constant List of the values in this enum, in order of their declaration.